#<profile4xi profile = "02" />
# -------------------------------------------------------------------------------------------------
#<program4xi program = "xmllistener4xi.py">
#<abstract4xi abstract = "provides the class XmlListener4Xi"/>
#<refer4xi reference = "connection.py"/>
#<state4xi status = "ACK4tagging; ACK4moduletesting; NACK4systemtesting; [Rel 7.21]"/>
#<note4xi note = "XmlListener4Xi compared to XmlListener of connection.py and found no changes due to Rel 7.21"/>
# -------------------------------------------------------------------------------------------------

# -------------------------------------------------------------------------------------------------
# Public API
# -------------------------------------------------------------------------------------------------
#<interface4xi interface = " 
__all__ = [ 'XmlListener4Xi' ] 
#"
#/>

# -------------------------------------------------------------------------------------------------
# Standard Imports                          
# -------------------------------------------------------------------------------------------------
#<standardize4xi standard = "
import errno
import io
import itertools
import os
import pickle
import select
import socket
import struct
import sys
import time
import tempfile
try:
    import _winapi
    from _winapi import WAIT_OBJECT_0, WAIT_TIMEOUT, INFINITE
except ImportError:
    if sys.platform == 'win32':
        raise
    _winapi = None
    
import hmac   
#"
#/>

# -------------------------------------------------------------------------------------------------
# Multiprocessing Imports                          
# -------------------------------------------------------------------------------------------------
#<process4xi process = "
import _multiprocessing
from multiprocessing.connection import ConnectionWrapper
from multiprocessing.connection import XmlListener
#"
#/>


# -------------------------------------------------------------------------------------------------
# DragonXi imports                              
# -------------------------------------------------------------------------------------------------
#<dragonize4xi dragonization = "
from ace_object4xi import ace_object4xi
from listener4xi import Listener4Xi
from connectionwrapper4xi import ConnectionWrapper4Xi
from print4xi import print4xi
from reason_object4xi import reason_object4xi
from sense_object4xi import sense_object4xi
from time4xi import time4xi
#"
#/>

# -------------------------------------------------------------------------------------------------
# DragonXi Globals                            
# ------------------------------------------------------------------------------------------------
#<globalize4xi globalization = "
global xmlrpclib4xi
#"
#/>
 

# =================================================================================================
#<class4xi class = "XmlListener4Xi" base = "Listener4Xi" child = "None"
#   synopsis = "XML Listener"
#   usage = "
#       listener_client4xi.py:
#           listener_client4xi = {
#                                 'pickle' : (Listener4Xi, Client4Xi),
#                              'xmlrpclib' : (XmlListener4Xi, XmlClient4Xi)}
#"
#>
# =================================================================================================
class XmlListener4Xi(Listener4Xi):
    '''
    XML Listener
    '''    

    
    # ---------------------------------------------------------------------------------------------
    #<methodize4xi method = "accept-of-XmlListener4Xi" usage = "accepts">
    # ---------------------------------------------------------------------------------------------
    def accept(self):
        '''
        accepts
        '''
        
        global xmlrpclib4xi
        
        class2print = "XmlListener4Xi"
        method2print = "accept"
        
        message2print = "{started" + "; accept-of-XmlListener4Xi-started: " + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)    
                 
                                
         
        # -----------------------------------------------------------------------------------------    
        #
        # -----------------------------------------------------------------------------------------                 
        ack2client = False
        nack2client = True
        try:
         
            import xmlrpc.client as xmlrpclib4xi        

            message2print = "{imported" + "; xmlrpc-client-imported-by-accept-of-XmlListener4Xi: " + str(xmlrpc.client) + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)         
                    
            object2xi = Listener4Xi.accept(self)
            
            message2print = "{set" + "; object2xi-set-by-accept-of-XmlListener4Xi to: " + str(object2xi)  + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)    
            
            message2print = "{passing" + "; object-passing-to-ConnectionWrapper4Xi-by-accept-of-XmlListener4Xi: " + str(object2xi) + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)            
                            
            message2print = "{passing" + "; xml-dumps-passing-to-ConnectionWrapper4Xi-by-accept-of-XmlListener4Xi: " + str(_xml_dumps) + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)                             
            
            message2print = "{passing" + "; xml-loads-passing-to-ConnectionWrapper4Xi-by-accept-of-XmlListener4Xi: " + str(_xml_loads) + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print) 
            
            message2print = "{returning" + "; ConnectionWrapper4Xi-class-returning-by-accept-of-XmlListener4Xi: " + str(ConnectionWrapper4Xi) + "; time: " + time4xi() + "}" 
            print4xi(class2print, method2print, message2print)  
            
            ack2client = True
            
            message2print = "{set" + "; ack2client-set-by-accept-of-XmlListener4Xi to: " + str(ack2client)  + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)    
            
                            
                        
            return ConnectionWrapper4Xi(object2xi, _xml_dumps, _xml_loads)
            
        except:
        
            message2print = "{yielded" + "; nack2client-yielded-by-accept-of-XmlListener4Xi: " + str(nack2client)  + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print) 
        
            return ConnectionWrapper(object2xi, _xml_dumps, _xml_loads)  
            
    #</methodize4xi>
    
                                       
    # ---------------------------------------------------------------------------------------------
    #<methodize4xi method = "sense-of-XmlListener4Xi" usage = "XmlListener4Xi class objects">
    # ---------------------------------------------------------------------------------------------
    def sense(self):
        '''
        senses XmlListener4Xi class objects
        '''
 
        
        class2print = 'XmlListener4Xi'
        method2print = 'sense'
        

        
        # -----------------------------------------------------------------------------------------
        #
        # -----------------------------------------------------------------------------------------  
        message2print = "{sensing" + "; XmlListener4Xi-sensing-by-sense-of-XmlListener4Xi: " + str(XmlListener4Xi)  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)         
                        
        
        # -----------------------------------------------------------------------------------------
        # get sensed knowledge for this object
        # -----------------------------------------------------------------------------------------        
        kb2xi = sense_object4xi(self)
        
        message2print = "{got" + "; kb2xi-got-by-sense-of-XmlListener4Xi: " + str(kb2xi)  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)
                        
        
        # -----------------------------------------------------------------------------------------
        # add knowledge specific to this object
        # format example: kb2xi['time2xi'] = time4xi() #adding time 
        # -----------------------------------------------------------------------------------------         
    
        message2print = "{sensed" + "; XmlListener4Xi-sensed-by-sense-of-XmlListener4Xi: " + str(XmlListener4Xi)  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)     
        
        # -----------------------------------------------------------------------------------------
        # 
        # -----------------------------------------------------------------------------------------         
        message2print = "{returning" + "; kb2xi-returning-by-sense-of-XmlListener4Xi: " + str(kb2xi) + "; time: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)    
                               
          
        return kb2xi
        
        # -----------------------------------------------------------------------------------------
        #
        # -----------------------------------------------------------------------------------------        
    #</methodize4xi>
    
        
    # ---------------------------------------------------------------------------------------------
    #<methodize4xi method = "reason-of-XmlListener4Xi" usage = "reasons XmlListener4Xi class objects">
    # ---------------------------------------------------------------------------------------------
    def reason(self):
        '''
        reasons XmlListener4Xi class objects
        '''

        
        class2print = 'XmlListener4Xi'
        method2print = 'reason'

        message2print = "{started" + "; reason-of-XmlListener4Xi-started: " + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)    
                 
                                
        message2print = "{reasoning" + "; XmlListener4Xi-reasoning-by-reason-of-XmlListener4Xi: " + str(XmlListener4Xi) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print) 
                        
        # -----------------------------------------------------------------------------------------
        #
        # -----------------------------------------------------------------------------------------

        
        # -----------------------------------------------------------------------------------------
        # get reasoned knowledge for this object
        # -----------------------------------------------------------------------------------------         
        kb4xi = reason_object4xi(self)
        
        message2print = "{got" + "; kb4xi-got-by-reason-of-XmlListener4Xi: " + str(kb4xi)  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)
                        

        
        # -----------------------------------------------------------------------------------------
        # add knowledge specific to this object
        # format example: kb4xi['time2xi'] = time4xi() #adding time 
        # -----------------------------------------------------------------------------------------          
        
        
          
        message2print = "{reasoned" + "; XmlListener4Xi-reasoned-by-reason-of-XmlListener4Xi: " + str(XmlListener4Xi) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)         
    
        
        # -----------------------------------------------------------------------------------------
        #
        # -----------------------------------------------------------------------------------------        
        message2print = "{returning" + "; kb4xi-returning-by-reason-of-XmlListener4Xi: " + str(kb4xi) + "; time: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)    
                        
        return kb4xi
        
        # -----------------------------------------------------------------------------------------
        #
        # -----------------------------------------------------------------------------------------            
    #</methodize4xi>
    
    
    # ---------------------------------------------------------------------------------------------
    #<methodize4xi method = "ace-of-XmlListener4Xi" usage = "aces XmlListener4Xi class objects ">
    # ---------------------------------------------------------------------------------------------
    def ace(self):
        '''
        aces XmlListener4Xi class objects 
        '''

        class2print = 'XmlListener4Xi'
        method2print = 'ace'
        
         
        message2print = "{started" + "; ace-of-XmlListener4Xi-started: " + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)    
                 
                                
        # -----------------------------------------------------------------------------------------
        #
        # -----------------------------------------------------------------------------------------
        message2print = "{acing" + "; XmlListener4Xi-acing-by-ace-of-XmlListener4Xi: " + str(XmlListener4Xi) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)         
                        
        
        # -----------------------------------------------------------------------------------------
        # get aced knowledge for this object
        # -----------------------------------------------------------------------------------------        
        kb8xi = ace_object4xi(self)  
        
        message2print = "{got" + "; kb8xi-got-by-ace-of-XmlListener4Xi: " + str(kb8xi)  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)
                


        # -----------------------------------------------------------------------------------------
        # add knowledge specific to this object
        # format example: kb8xi['time2xi'] = time4xi() #adding time 
        # -----------------------------------------------------------------------------------------              
        
          
        message2print = "{aced" + "; XmlListener4Xi-aced-by-ace-of-XmlListener4Xi: " + str(XmlListener4Xi) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)           
        
        # -----------------------------------------------------------------------------------------
        #
        # -----------------------------------------------------------------------------------------        
        message2print = "{returning" + "; kb8xi-returning-by-ace-of-XmlListener4Xi: " + str(kb8xi) + "; time: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)    
                                
        
        return kb8xi
        
        # -----------------------------------------------------------------------------------------
        #
        # -----------------------------------------------------------------------------------------            
    #</methodize4xi>
#</class4xi>
#</program4xi>

     

# -------------------------------------------------------------------------------------------------
# Recorded History                             
# ------------------------------------------------------------------------------------------------- 
#<record4xi record = "
#   test_none4xi.txt
#   sense-none4xi.xml
#   reason-none4xi.xml
#   ace-none4xi.xml
#"
#>


# -------------------------------------------------------------------------------------------------
# Legal Notice                             
# ------------------------------------------------------------------------------------------------- 
#<protect4xi protection = "copyright"
#   owner = "Small & Smart"
#   rights = "All rights reserved"
#   state = "California"
#   country = "United States of America"
#   references = "Legal notice at www.dragonxi.com; www.yourdragonxi.com; www.yourdragonxi.org; www.dragon2xi.com/; www.dragon4xi.com/; www.dragon8xi.com/ " 
#   codes = "Codes established in California and applicable to corporations in California"
#   compliance = "The California Law"
#   court = "Supreme Court of California, 350 McAllister Street, San Francisco, CA 94102-4783"
#/>
 

#<end4xi end = "
# -------------------------------------------------------------------------------------------------
# end of xmllistener4xi.py                           
# ------------------------------------------------------------------------------------------------- 
#"
#/>
